## 券商每月荐股

接口：broker_recommend

描述：获取券商月度金股，一般1日~3日内更新当月数据

限量：单次最大1000行数据，可循环提取

积分：积分达到2000即可调用，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| month | str | Y | 月度（YYYYMM） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| month | str | Y | 月度 |
| broker | str | Y | 券商 |
| ts_code | str | Y | 股票代码 |
| name | str | Y | 股票简称 |

接口示例

```python
#获取查询月份券商金股
df = pro.broker_recommend(month='202106')
```

数据示例

```python
month broker    ts_code  name
0    202106   东兴证券  000066.SZ  中国长城
```